@@ -85,8 +85,8 @@
  *          3 Kislev    29   30   30         29   30   30 (variable)
  *          4 Tevet     29   29   29         29   29   29
  *          5 Shevat    30   30   30         30   30   30
- *          6 Adar I    29   29   29         30   30   30 (variable)
- *          7 Adar II   --   --   --         29   29   29 (optional)
+ *          6 Adar I    --   --   --         30   30   30 (optional)
+ *          7 Adar (II) 29   29   29         29   29   29
  *          8 Nisan     30   30   30         30   30   30
  *          9 Iyyar     29   29   29         29   29   29
  *         10 Sivan     30   30   30         30   30   30
@@ -100,8 +100,8 @@
  *     have multiple possible spellings in the Roman character set.  I have
  *     chosen to use the spellings found in the Encyclopedia Judaica.
  *
- *     Adar II, the month added for leap years, is sometimes referred to as
- *     the 13th month, but I have chosen to assign it the number 7 to keep
+ *     Adar I, the month added for leap years, is sometimes referred to as
+ *     the 13th month, but I have chosen to assign it the number 6 to keep
  *     the months in chronological order.  This may not be consistent with
  *     other numbering schemes.
  *
@@ -260,7 +260,7 @@
  *
  **************************************************************************/
 
-#if defined(PHP_WIN32) && _MSC_VER >= 1200
+#if defined(PHP_WIN32)
 #pragma setlocale("english")
 #endif
 
@@ -287,7 +287,7 @@
 #define AM3_11_20 ((9 * HALAKIM_PER_HOUR) + 204)
 #define AM9_32_43 ((15 * HALAKIM_PER_HOUR) + 589)
 
-static int monthsPerYear[19] =
+int monthsPerYear[19] =
 {
 12, 12, 13, 12, 12, 13, 12, 13, 12, 12, 13, 12, 12, 13, 12, 12, 13, 12, 13
 };
@@ -298,16 +298,17 @@ static int yearOffset[19] =
 	136, 148, 160, 173, 185, 197, 210, 222
 };
 
-char *JewishMonthName[14] =
+/* names for leap (13-month) year */
+char *JewishMonthNameLeap[14] =
 {
-	"",
+	"", 
 	"Tishri",
 	"Heshvan",
 	"Kislev",
 	"Tevet",
 	"Shevat",
-	"AdarI",
-	"AdarII",
+	"Adar I",
+	"Adar II",
 	"Nisan",
 	"Iyyar",
 	"Sivan",
@@ -316,8 +317,48 @@ char *JewishMonthName[14] =
 	"Elul"
 };
 
+/* names for regular year */
+char *JewishMonthName[14] =
+{
+	"", 
+	"Tishri",
+	"Heshvan",
+	"Kislev",
+	"Tevet",
+	"Shevat",
+	"",
+	"Adar",
+	"Nisan",
+	"Iyyar",
+	"Sivan",
+	"Tammuz",
+	"Av",
+	"Elul"
+};
+
+/* names for leap (13-month) year */
+char *JewishMonthHebNameLeap[14] =
+{
+	"", 
+	"",
+	"",
+	"",
+	"",
+	"",
+	" '",
+	" '",
+	"",
+	"",
+	"",
+	"",
+	"",
+	""
+};
+
+/* names for regular year */
 char *JewishMonthHebName[14] =
 {
+	"", 
 	"",
 	"",
 	"",
@@ -325,7 +366,6 @@ char *JewishMonthHebName[14] =
 	"",
 	"",
 	"",
-	"' ",
 	"",
 	"",
 	"",
@@ -342,12 +382,12 @@ char *JewishMonthHebName[14] =
  * (called dehiyyot) delays it.  These 4 rules can delay the start of the
  * year by as much as 2 days.
  */
-static long int Tishri1(
+static zend_long Tishri1(
 						   int metonicYear,
-						   long int moladDay,
-						   long int moladHalakim)
+						   zend_long moladDay,
+						   zend_long moladHalakim)
 {
-	long int tishri1;
+	zend_long tishri1;
 	int dow;
 	int leapYear;
 	int lastWasLeapYear;
@@ -389,10 +429,10 @@ static long int Tishri1(
  */
 static void MoladOfMetonicCycle(
 								   int metonicCycle,
-								   long int *pMoladDay,
-								   long int *pMoladHalakim)
+								   zend_long *pMoladDay,
+								   zend_long *pMoladHalakim)
 {
-	register unsigned long int r1, r2, d1, d2;
+	register zend_ulong r1, r2, d1, d2;
 
 	/* Start with the time of the first molad after creation. */
 	r1 = NEW_MOON_OF_CREATION;
@@ -428,14 +468,14 @@ static void MoladOfMetonicCycle(
  * us to avoid calculating the length of the year in most cases.
  */
 static void FindTishriMolad(
-							   long int inputDay,
+							   zend_long inputDay,
 							   int *pMetonicCycle,
 							   int *pMetonicYear,
-							   long int *pMoladDay,
-							   long int *pMoladHalakim)
+							   zend_long *pMoladDay,
+							   zend_long *pMoladHalakim)
 {
-	long int moladDay;
-	long int moladHalakim;
+	zend_long moladDay;
+	zend_long moladHalakim;
 	int metonicCycle;
 	int metonicYear;
 
@@ -483,8 +523,8 @@ static void FindStartOfYear(
 							   int year,
 							   int *pMetonicCycle,
 							   int *pMetonicYear,
-							   long int *pMoladDay,
-							   long int *pMoladHalakim,
+							   zend_long *pMoladDay,
+							   zend_long *pMoladHalakim,
 							   int *pTishri1)
 {
 	*pMetonicCycle = (year - 1) / 19;
@@ -506,14 +546,14 @@ static void FindStartOfYear(
  * range 1 to 13 inclusive; *pDay will be in the range 1 to 30 inclusive.
  */
 void SdnToJewish(
-					long int sdn,
+					zend_long sdn,
 					int *pYear,
 					int *pMonth,
 					int *pDay)
 {
-	long int inputDay;
-	long int day;
-	long int halakim;
+	zend_long inputDay;
+	zend_long day;
+	zend_long halakim;
 	int metonicCycle;
 	int metonicYear;
 	int tishri1;
@@ -588,11 +628,11 @@ void SdnToJewish(
 				(*pMonth)--;
 				(*pDay) += 30;
 			} else {
-				*pMonth = 6;
+				*pMonth = 7;
 				*pDay = inputDay - tishri1 + 207;
 				if (*pDay > 0)
 					return;
-				(*pMonth)--;
+				(*pMonth) -= 2;
 				(*pDay) += 30;
 			}
 			if (*pDay > 0)
@@ -644,18 +684,18 @@ void SdnToJewish(
  * value.  To verify that a date is valid, convert it to SDN and then back
  * and compare with the original.
  */
-long int JewishToSdn(
+zend_long JewishToSdn(
 						int year,
 						int month,
 						int day)
 {
-	long int sdn;
+	zend_long sdn;
 	int metonicCycle;
 	int metonicYear;
 	int tishri1;
 	int tishri1After;
-	long int moladDay;
-	long int moladHalakim;
+	zend_long moladDay;
+	zend_long moladHalakim;
 	int yearLength;
 	int lengthOfAdarIAndII;
 
